/*
    Video maid
    copyright (c) 1998-2004 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/
#ifndef __THREAD_H__
#define __THREAD_H__


#include "vmaid.h"


#ifdef __cplusplus
extern "C" {
#endif /* __cplusplus */


#define THREAD_MODE_EXIT 0
#define THREAD_MODE_OPEN 1
#define THREAD_MODE_SAVE 2
#define THREAD_MODE_FRAME 3
#define THREAD_MODE_REVERSE 4
#ifndef USE_THREAD
# define THREAD_ID_STANDARD 0
# define THREAD_ID_CLOSE 1
#endif /* not USE_THREAD */


typedef struct ThreadList_Tag
{
  gboolean userbreak;   /* ja:TRUE:継続,FALSE:中断要求 */
  gint mode;            /* ja:0:終了,1:開く,2:保存,3:フレーム数,4:反転 */
  gint percent;         /* ja:進行状況(0...100) */
#ifdef USE_THREAD
  GThread *id;
#else /* not USE_THREAD */
  gint id;
#endif /* not USE_THREAD */
} ThreadList;


/******************************************************************************
*                                                                             *
* ja:スレッド関数群                                                           *
*                                                                             *
******************************************************************************/
/*  ja:リストに加える
      id,スレッドID
    mode,モード(0:終了,1:開く,2:保存,3:フレーム数,4:反転)
    file,ファイル名
     RET,TRUE:正常終了,FALSE:エラー                                         */
#ifdef USE_THREAD
gboolean
thread_insert (GThread     *id,
               const gint   mode,
               const gchar *file);
#else /* not USE_THREAD */
gboolean
thread_insert (gint          id,
               const gint    mode,
               const gchar *file);
#endif /* not USE_THREAD */


/*  ja:リストから削除する
     id,スレッドID
    RET,TRUE:正常終了,FALSE:エラー                                          */
#ifdef USE_THREAD
gboolean
thread_delete (GThread *id);
#else /* not USE_THREAD */
gboolean
thread_delete(gint id);
#endif /* not USE_THREAD */


/*  ja:リストを更新する
         id,スレッドID
    percent,進行状況
        RET,TRUE:継続,FALSE:中断                                            */
#ifdef USE_THREAD
gboolean
thread_idling (GThread    *id,
               const gint  percent);
#else /* not USE_THREAD */
gboolean
thread_idling (gint       id,
               const gint percent);
#endif /* not USE_THREAD */


/*  ja:スレッドを停止させる
    all,TRUE:すべてのスレッド,FALSE:選択されたスレッドのみ
    RET,TRUE:正常終了,FALSE:エラー                                          */
gboolean
thread_break (const gboolean all);


/*  ja:プログラムの終了(独立スレッド)                                       */
void *
close_program (void);


#ifdef __cplusplus
}
#endif /* __cplusplus */


#endif
